<template>
  <div class="container-fluid">
    <div class="row">
      <h3 class="text-center text-[22px]">Deleted Students</h3>
    </div>

    <div class="flex flex-wrap items-center -mx-4 pb-3 gap-y-3">
      <div class="w-full lg:w-5/12 px-4">
        <label
          for="default-search"
          class="mb-2 text-sm font-medium text-gray-900 sr-only dark:text-white"
        >Search</label>
        <div class="relative">
          <input
            v-model="search"
            type="search"
            id="default-search"
            class="block w-full p-4 ps-4 text-sm text-gray-900 rounded-lg bg-gray-50 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500"
            placeholder="Reg No, Name, Mobile, Roll No"
            required
          />
          <button
            type="submit"
            class="text-white absolute end-2.5 bottom-2.5 bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm px-4 py-2 dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800"
            @click="getDeletedStudents"
          >Search</button>
        </div>
      </div>
      <div class="w-full lg:w-7/12 px-4">
        <div
          class="sm:flex items-center lg:justify-end sm:space-x-3 space-y-3 sm:space-y-0 overflow-x-auto scrollbar-none"
        >
          <button
            type="button"
            class="py-2.5 px-5 text-sm font-medium text-white focus:outline-none text-white bg-green-700 hover:bg-green-800 rounded-lg focus:z-10 focus:ring-4 focus:ring-gray-100 dark:focus:ring-gray-700 dark:bg-gray-800 dark:text-gray-400 dark:border-gray-600 dark:hover:text-white dark:hover:bg-gray-700 disabled:cursor-default"
            @click="backToGeneralStudent()"
          >Back to General Student List</button>
        </div>
      </div>
    </div>

    <div class="flex flex-col bg-white p-5 mt-4">
      <div class="overflow-x-auto sm:-mx-6 lg:-mx-8">
        <div class="inline-block min-w-full py-2 sm:px-6 lg:px-8">
          <div class="overflow-hidden">
            <table
              class="min-w-full border border-neutral-200 text-center text-sm font-light text-surface dark:border-white/10 dark:text-white"
            >
              <thead class="border-b border-neutral-200 font-medium dark:border-white/10">
                <tr>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >#</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Registration No</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Name</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Mobile</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Branch Name</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Roll No</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Delete Reason</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Action</th>
                </tr>
              </thead>
              <tbody>
                <tr
                  v-for="(student, index) in students"
                  :key="index"
                  class="border-b border-neutral-200 dark:border-white/10"
                >
                  <td
                    class="whitespace-nowrap border-e border-neutral-200 px-6 py-4 font-medium dark:border-white/10"
                  >{{ ++index + indexValueForPagination }}</td>
                  <td
                    class="whitespace-nowrap border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >{{student.reg_no}}</td>
                  <td
                    class="whitespace-nowrap border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >{{student.student_name}}</td>
                  <td
                    class="whitespace-nowrap px-6 py-4 border-e border-neutral-200"
                  >{{student.mobile}}</td>
                  <td
                    v-if="student.branch"
                    class="whitespace-nowrap px-6 py-4 border-e border-neutral-200"
                  >{{student.branch.name}}</td>
                  <td
                    class="whitespace-nowrap px-6 py-4 border-e border-neutral-200"
                  >{{student.roll_no}}</td>
                  <td
                    class="whitespace-nowrap px-6 py-4 border-e border-neutral-200"
                  >{{student.delete_reason}}</td>
                  <td class="whitespace-nowrap px-6 py-4 border-e border-neutral-200">
                    <button
                      class="rounded-lg px-4 py-2 bg-purple-700 text-green-100 hover:bg-green-800 duration-300"
                      @click="handleView(student.id)"
                    >View</button>
                  </td>
                </tr>
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>

    <a-pagination
      v-if="pagination.last_page > 1"
      :total="pagination.total"
      :show-total="(total) => `Total ${pagination.total} items`"
      :size="String(pagination.total)"
      :default-current="1"
      :defaultPageSize="pagination.to"
      v-model="current"
      @change="onChange"
      class="text-center"
      style="padding-bottom: 10px; margin-top: 15px"
    />
  </div>
</template>
  
<script>
import { Modal } from "ant-design-vue";

export default {
  data() {
    return {
      submitted: false,
      branch: [],
      students: [],
      search: "",
      perPage: 30,
      totalData: 0,
      indexValueForPagination: 0,
      studentDeleteReason: "",
      loading: false,
      pagination: {},
      current: 1,
      pageSize: "",
      studentDeleteId: "",
      studentDeletePermission: false
    };
  },
  watch: {
    search() {
      if (this.search.length == 0) {
        this.getDeletedStudents();
      }
    },
    query: function(newQuery, oldQuery) {
      if (newQuery === "") {
        this.getDeletedStudents();
      } else {
        this.search();
      }
    }
  },
  methods: {
    backToGeneralStudent(){
        return this.$router.push({
        name: "students",
      });
    },
    onChange(next) {
      this.current = next;
      this.indexValueForPagination = 0;
      if (next == 1) return this.getDeletedStudents(next);

      this.indexValueForPagination =
        (next + this.indexValueForPagination) * this.perPage - this.perPage;
      this.getDeletedStudents(next);
    },
    handleView(id) {
      var url = "/students#/view/" + id;
      window.open(url, "_blank");
    },
    handleCurrentChange(next) {
      this.indexValueForPagination = 0;
      if (next == 1) return this.getDeletedStudents(next);

      this.indexValueForPagination =
        (next + this.indexValueForPagination) * this.perPage - this.perPage;
      this.getDeletedStudents(next);
    },
    handleSearch() {
      if (this.search.length > 0 || this.search.length == 0) {
        this.getDeletedStudents();
      }
    },
    getDeletedStudents(nextPage = null) {
      this.loading = true;
      this.openStudentModal = false;
      let url = `/deleted-student-list?per_page=${this.perPage}`;

      if (nextPage) {
        url += `&page=${nextPage}`;
      }
      if (this.search.length) {
        url += `&search=${this.search}`;
      }
      axios
        .get(url)
        .then(response => {
          this.students = response.data.students.data;
          this.branch = response.data.branch_centre;
          this.totalData = response.data.students.total;
          this.pagination = response.data.students;
          this.pageSize =
            parseInt(this.pagination.total) / parseInt(this.pagination.to);
          this.loading = false;
        })
        .catch(error => {
          this.loading = false;
        });
    }
  },

  mounted() {
    this.getDeletedStudents(this.pageSize);
  }
};
</script>
  